@@ -439,7 +439,6 @@ class WeatherProcessor:
             response_df = self.__safe_convert(response, [])
             if response_df.shape[0] > 0:
                 if_updated = True
-                print(response_df)
                 response_df = response_df[
                     ["station", "datatype", "date", "value"]
                 ].rename(columns={"station": "station_id"})
@@ -643,7 +642,7 @@ class BayesModelBuilder:
             for src in src_list:
                 if src != dest:
                     term_list.append(
-                        "tau_{}_{} * {}[{}]".format(src, dest, src, index)
+                        "tau_{}_{} * {}[{}-1]".format(src, dest, src, index)
                     )
                 else:
                     autoregressive = True
